@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from collections.abc import AsyncIterable
 from functools import cached_property
 from typing import Optional
 
@@ -8,12 +9,15 @@ from ..driver import Driver
 from ..parallel import gather_
 from ..state import DB
 from ..tracker import Tracker
-from ..utils import allow_singular, async_cached
+from ..utils import allow_singular, async_cached, matches_if_specified
 
 
 class Package(BaseModel, ABC):
     model_config = ConfigDict(
-        frozen=True, arbitrary_types_allowed=True, ignored_types=(cached_property,)
+        frozen=True,
+        arbitrary_types_allowed=True,
+        ignored_types=(cached_property,),
+        extra="forbid",
     )
 
     def __hash__(self) -> int:
@@ -31,9 +35,11 @@ class Package(BaseModel, ABC):
     db: DB
     driver_: Driver = Field(..., alias="driver")
 
+    root: bool = False
+
     @property
     def driver(self) -> Driver:
-        return self.driver_
+        return self.driver_.with_root(self.root)
 
     @property
     def name(self) -> str:
@@ -63,12 +69,13 @@ class Package(BaseModel, ABC):
         pass
 
     async def applicable(self) -> bool:
-        def check_os(name: str) -> bool:
-            return self.os is None or name in self.os
-
         os = await self.driver.os()
         return os.switch_(
-            linux=lambda linux: check_os("linux")
-            and (self.distribution is None or linux.distribution in self.distribution),
-            macos=lambda: check_os("darwin"),
+            linux=lambda linux: matches_if_specified(self.os, "linux")
+            and matches_if_specified(self.distribution, linux.distribution),
+            macos=lambda: matches_if_specified(self.os, "darwin"),
         )
+
+    async def prerequisites(self) -> AsyncIterable["Package"]:
+        return
+        yield
