@@ -3,6 +3,7 @@ from functools import cached_property
 from typing import Optional
 
 from ..state import VERSIONS, Storage, Version
+from ..tracker import Tracker
 from .base import Package
 
 
@@ -24,6 +25,6 @@ class ManualVersion(Package, ABC):
     async def cache_version(self) -> None:
         self.versions[self.name] = Version(version=await self.get_remote_version())
 
-    async def install(self) -> None:
-        await super().install()
+    async def install(self, *, tracker: Tracker) -> None:
+        await super().install(tracker=tracker)
         await self.cache_version()
