@@ -3,7 +3,7 @@ from typing import Optional
 import trio
 from pydantic import Field
 
-from ..compute import Value
+from ..compute import Value, compute
 from ..tracker import Tracker
 from ..utils import allow_singular_none, async_cached, url_version
 from .installer import make_installer
@@ -28,12 +28,12 @@ class SystemPackage(ManualVersion):
     @async_cached
     async def url(self) -> Optional[str]:
         if self.url_:
-            return await self.url_.compute()
+            return await compute(self.url_)
         return None
 
     async def get_remote_version(self) -> str:
         if url := await self.url():
-            return url_version(url)
+            return await url_version(url)
         if self.auto_updates:
             return "latest"
         return await (await self.installer()).latest_version(self.system)
@@ -49,9 +49,10 @@ class SystemPackage(ManualVersion):
 
     async def postinstall_linux(self):
         if self.services:
-            await self.driver.with_root(True).run("systemctl", "daemon-reload")
+            driver = self.driver.with_root(True)
+            await driver.run("systemctl", "daemon-reload")
             for service in self.services:
-                await self.driver.with_root(True).run("systemctl", "enable", service)
+                await driver.run("systemctl", "enable", "--now", service)
 
     async def postinstall_macos(self):
         pass
