@@ -1,7 +1,8 @@
+from collections.abc import AsyncIterator, Awaitable, Callable
 from contextlib import asynccontextmanager
 from dataclasses import dataclass
 from functools import partial
-from typing import AsyncIterator, Awaitable, Callable, Generic, Optional
+from typing import Generic, Optional
 
 import tqdm
 import trio
@@ -22,9 +23,9 @@ class PartialException:
 PartialResult = PartialException | PartialSuccess[T]
 
 
+@dataclass
 class PartialResults(Exception, Generic[T]):
-    def __init__(self, results: list[PartialResult[T]]):
-        self.results = results
+    results: list[PartialResult[T]]
 
 
 TERMINAL_LOCK = trio.Lock()
@@ -47,7 +48,7 @@ async def parallel_map_tqdm(
                     progress.update(1)
                 return result
 
-            return await gather_(*(partial(action_and_update, item) for item in items))
+            return await gather(*(partial(action_and_update, item) for item in items))
         finally:
             async with TERMINAL_LOCK:
                 CURRENT_TQDM = None
@@ -66,27 +67,24 @@ async def parallel_map_pause() -> AsyncIterator[None]:
                 progress.refresh()
 
 
-async def gather(*tasks: Callable[[], Awaitable[T]]) -> list[PartialResult[T]]:
-    async def collect(
-        index: int,
-        task: Callable[[], Awaitable[T]],
-        results: dict[int, PartialResult[T]],
-    ):
-        try:
-            results[index] = PartialSuccess(result=await task())
-        except BaseException as e:  # pylint:disable=broad-exception-caught
-            results[index] = PartialException(exception=e)
-
+async def gather(*tasks: Callable[[], Awaitable[T]]) -> list[T]:
     results: dict[int, PartialResult[T]] = {}
 
     async with trio.open_nursery() as nursery:
+
+        async def collect(index: int, task: Callable[[], Awaitable[T]]):
+            try:
+                results[index] = PartialSuccess(result=await task())
+            except Exception as e:  # pylint:disable=broad-exception-caught
+                results[index] = PartialException(exception=e)
+            except BaseException as e:  # pylint:disable=broad-exception-caught
+                results[index] = PartialException(exception=e)
+                nursery.cancel_scope.cancel()
+
         for index, task in enumerate(tasks):
-            nursery.start_soon(collect, index, task, results)
-    return [results[i] for i in range(len(tasks))]
+            nursery.start_soon(collect, index, task)
 
-
-async def gather_(*tasks: Callable[[], Awaitable[T]]) -> list[T]:
-    partial_results = await gather(*tasks)
+    partial_results = [results[i] for i in range(len(tasks))]
 
     return [
         (
@@ -96,3 +94,14 @@ async def gather_(*tasks: Callable[[], Awaitable[T]]) -> list[T]:
         )
         for result in partial_results
     ]
+
+
+async def gather_(*tasks: Callable[[], Awaitable[T]]) -> list[T]:
+    try:
+        return await gather(*tasks)
+    except PartialResults as exc:
+        for result in exc.results:
+            if isinstance(result, PartialException):
+                raise result.exception from None
+        # Must have at least one exception inside PartialResults
+        raise AssertionError("PartialResults is empty") from None  # pragma: no cover
