@@ -1,3 +1,4 @@
-from .base import DB, DB_PATH, Storage, storage
+from .base import Storage, storage
+from .db import DB, DB_PATH
 from .installed import INSTALLED_FILES, InstalledFile
 from .version import VERSIONS, Version
