@@ -1,9 +1,10 @@
 import subprocess
+from collections.abc import Awaitable, Callable, Iterable
 from functools import wraps
 from pathlib import Path
-from typing import Any, Callable, Coroutine, Iterable, Optional, TypeVar, overload
+from typing import Any, Optional, TypeVar, overload
 
-import requests
+import httpx
 import trio
 from pydantic import field_validator
 
@@ -35,6 +36,10 @@ def allow_singular_none(field: str) -> Any:
     return field_validator(field, mode="before")(lambda cls, x: unsome(x))
 
 
+def matches_if_specified(possibilities: Optional[list[T]], value: T) -> bool:
+    return possibilities is None or value in possibilities
+
+
 def intercalate(delimiter: T, items: Iterable[Iterable[T]]) -> list[T]:
     it = iter(items)
     try:
@@ -75,8 +80,17 @@ def flatten(items: Iterable[Iterable[T]]) -> list[T]:
     return [item for sublist in items for item in sublist]
 
 
-def url_version(url: str) -> str:
-    head_response = requests.head(url, allow_redirects=True)
+http_client = httpx.AsyncClient()
+
+
+async def http_get(url: str, headers: Optional[dict[str, str]] = None) -> str:
+    response = await http_client.get(url, headers=headers)
+    response.raise_for_status()
+    return response.text
+
+
+async def url_version(url: str) -> str:
+    head_response = await http_client.head(url, follow_redirects=True)
     return head_response.headers["etag"]
 
 
@@ -89,46 +103,51 @@ async def repo_version(repo: str) -> str:
     return (await run_output("git", "ls-remote", repo, "HEAD")).split()[0]
 
 
+def with_extensions(name: str, extensions: list[str]) -> list[str]:
+    if any(name.endswith(f".{ext}") for ext in extensions):
+        return [name]
+    return [f"{name}.{ext}" for ext in extensions]
+
+
 def raise_(exception: BaseException) -> Any:
     raise exception
 
 
-AsyncRet = Coroutine[Any, Any, T]
+@overload
+def async_cached(fn: Callable[[], Awaitable[T]]) -> Callable[[], Awaitable[T]]: ...
 
 
 @overload
-def async_cached(fn: Callable[[], AsyncRet[T]]) -> Callable[[], AsyncRet[T]]: ...
-
-
-@overload
-def async_cached(fn: Callable[[U], AsyncRet[T]]) -> Callable[[U], AsyncRet[T]]: ...
+def async_cached(fn: Callable[[U], Awaitable[T]]) -> Callable[[U], Awaitable[T]]: ...
 
 
 @overload
 def async_cached(
-    fn: Callable[[U, V], AsyncRet[T]]
-) -> Callable[[U, V], AsyncRet[T]]: ...
+    fn: Callable[[U, V], Awaitable[T]]
+) -> Callable[[U, V], Awaitable[T]]: ...
 
 
-def async_cached(fn: Callable[..., AsyncRet[T]]) -> Callable[..., AsyncRet[T]]:
+def async_cached(fn: Callable[..., Awaitable[T]]) -> Callable[..., Awaitable[T]]:
     return _async_cached_lock(None, fn)
 
 
 @overload
-def async_cached_lock(fn: Callable[[], AsyncRet[T]]) -> Callable[[], AsyncRet[T]]: ...
-
-
-@overload
-def async_cached_lock(fn: Callable[[U], AsyncRet[T]]) -> Callable[[U], AsyncRet[T]]: ...
+def async_cached_lock(fn: Callable[[], Awaitable[T]]) -> Callable[[], Awaitable[T]]: ...
 
 
 @overload
 def async_cached_lock(
-    fn: Callable[[U, V], AsyncRet[T]]
-) -> Callable[[U, V], AsyncRet[T]]: ...
+    fn: Callable[[U], Awaitable[T]]
+) -> Callable[[U], Awaitable[T]]: ...
 
 
-def async_cached_lock(fn: Callable[..., AsyncRet[T]]) -> Callable[..., AsyncRet[T]]:
+@overload
+def async_cached_lock(
+    fn: Callable[[U, V], Awaitable[T]]
+) -> Callable[[U, V], Awaitable[T]]: ...
+
+
+def async_cached_lock(fn: Callable[..., Awaitable[T]]) -> Callable[..., Awaitable[T]]:
     return _async_cached_lock(trio.Lock(), fn)
 
 
@@ -144,8 +163,8 @@ NO_LOCK = NoLock()
 
 
 def _async_cached_lock(
-    lock: Optional[trio.Lock], fn: Callable[..., AsyncRet[T]]
-) -> Callable[..., AsyncRet[T]]:
+    lock: Optional[trio.Lock], fn: Callable[..., Awaitable[T]]
+) -> Callable[..., Awaitable[T]]:
     cache: dict[Any, T] = {}
 
     @wraps(fn)
